import type { CsvSettings } from './formats/csv/CsvSettings';
import type { IntermediateFilesStrategy } from './types/IntermediateFilesStrategy';
import type { string_email } from './types/typeAliases';
import type { string_name } from './types/typeAliases';
import type { string_url_image } from './types/typeAliases';
/**
 * Warning message for the generated sections and files files
 *
 * @private within the repository
 */
export declare const GENERATOR_WARNING = "\u26A0\uFE0F WARNING: This code has been generated so that any manual changes will be overwritten";
/**
 * Name for the Promptbook
 *
 * TODO: [🗽] Unite branding and make single place for it
 *
 * @public exported from `@promptbook/core`
 */
export declare const NAME = "Promptbook";
/**
 * Email of the responsible person
 *
 * @public exported from `@promptbook/core`
 */
export declare const ADMIN_EMAIL: string_email;
/**
 * Name of the responsible person for the Promptbook on GitHub
 *
 * @public exported from `@promptbook/core`
 */
export declare const ADMIN_GITHUB_NAME: string_name;
/**
 * Claim for the Promptbook
 *
 * TODO: [🗽] Unite branding and make single place for it
 *
 * @public exported from `@promptbook/core`
 */
export declare const CLAIM = "It's time for a paradigm shift. The future of software in plain English, French or Latin";
/**
 * Logo for the light theme
 *
 * TODO: [🗽] Unite branding and make single place for it
 *
 * @public exported from `@promptbook/core`
 */
export declare const LOGO_LIGHT_SRC: string_url_image;
/**
 * Logo for the dark theme
 *
 * TODO: [🗽] Unite branding and make single place for it
 *
 * @public exported from `@promptbook/core`
 */
export declare const LOGO_DARK_SRC: string_url_image;
/**
 * When the title is not provided, the default title is used
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_TITLE = "Untitled";
/**
 * Warning message for the generated sections and files files
 *
 * @private within the repository
 */
export declare const GENERATOR_WARNING_BY_PROMPTBOOK_CLI = "\u26A0\uFE0F WARNING: This code has been generated by `@promptbook/cli` so that any manual changes will be overwritten";
/**
 * The maximum number of iterations for a loops
 *
 * @private within the repository - too low-level in comparison with other `MAX_...`
 */
export declare const LOOP_LIMIT = 1000;
/**
 * The maximum number of iterations for a loops which adds characters one by one
 *
 * @private within the repository - too low-level in comparison with other `MAX_...`
 */
export declare const CHARACTER_LOOP_LIMIT = 100000;
/**
 * Strings to represent various values in the context of parameter values
 *
 * @public exported from `@promptbook/utils`
 */
export declare const VALUE_STRINGS: {
    readonly empty: "(nothing; empty string)";
    readonly null: "(no value; null)";
    readonly undefined: "(unknown value; undefined)";
    readonly nan: "(not a number; NaN)";
    readonly infinity: "(infinity; ∞)";
    readonly negativeInfinity: "(negative infinity; -∞)";
    readonly unserializable: "(unserializable value)";
};
/**
 * Small number limit
 *
 * @public exported from `@promptbook/utils`
 */
export declare const SMALL_NUMBER = 0.001;
/**
 * Timeout for the connections in milliseconds
 *
 * @private within the repository - too low-level in comparison with other `MAX_...`
 */
export declare const CONNECTION_TIMEOUT_MS: number;
/**
 * How many times to retry the connections
 *
 * @private within the repository - too low-level in comparison with other `MAX_...`
 */
export declare const CONNECTION_RETRIES_LIMIT = 5;
/**
 * Short time interval to prevent race conditions in milliseconds
 *
 * @private within the repository - too low-level in comparison with other `MAX_...`
 */
export declare const IMMEDIATE_TIME = 10;
/**
 * The maximum length of the (generated) filename
 *
 * @public exported from `@promptbook/core`
 */
export declare const MAX_FILENAME_LENGTH = 30;
/**
 * Strategy for caching the intermediate results for knowledge sources
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_INTERMEDIATE_FILES_STRATEGY: IntermediateFilesStrategy;
/**
 * The maximum number of (LLM) tasks running in parallel
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_MAX_PARALLEL_COUNT = 5;
/**
 * The maximum number of attempts to execute LLM task before giving up
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_MAX_EXECUTION_ATTEMPTS = 3;
/**
 * @@@
 * TODO: [🐝][main] !!! Use
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_MAX_KNOWLEDGE_SOURCES_SCRAPING_DEPTH = 3;
/**
 * @@@
 * TODO: [🐝][main] !!! Use
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_MAX_KNOWLEDGE_SOURCES_SCRAPING_TOTAL = 200;
/**
 * Where to store your books
 * This is kind of a "src" for your books
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_BOOKS_DIRNAME = "./books";
/**
 * Where to store the cache of executions for promptbook CLI
 *
 * Note: When the folder does not exist, it is created recursively
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_EXECUTIONS_CACHE_DIRNAME = "./.promptbook/executions-cache";
/**
 * Where to store the scrape cache
 *
 * Note: When the folder does not exist, it is created recursively
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_SCRAPE_CACHE_DIRNAME = "./.promptbook/scrape-cache";
/**
 * The name of the builded pipeline collection made by CLI `ptbk make` and for lookup in `createCollectionFromDirectory`
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_PIPELINE_COLLECTION_BASE_FILENAME = "index";
/**
 * The thresholds for the relative time in the `moment` NPM package.
 *
 * @see https://momentjscom.readthedocs.io/en/latest/moment/07-customization/13-relative-time-threshold/
 * @private within the repository - too low-level in comparison with other constants
 */
export declare const MOMENT_ARG_THRESHOLDS: {
    readonly ss: 3;
};
/**
 * @@@
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_REMOTE_URL = "https://api.pavolhejny.com/";
/**
 * @@@
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_REMOTE_URL_PATH = "/promptbook/socket.io";
/**
 * @@@
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_CSV_SETTINGS: CsvSettings;
/**
 * @@@
 *
 * @public exported from `@promptbook/core`
 */
export declare let DEFAULT_IS_VERBOSE: boolean;
/**
 * @@@
 *
 * Note: This is experimental feature
 *
 * @public exported from `@promptbook/core`
 */
export declare function SET_IS_VERBOSE(isVerbose: boolean): void;
/**
 * @@@
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_IS_AUTO_INSTALLED = false;
/**
 * Function name for generated function via `ptbk make` to get the pipeline collection
 *
 * @public exported from `@promptbook/core`
 */
export declare const DEFAULT_GET_PIPELINE_COLLECTION_FUNCTION_NAME = "getPipelineCollection";
/**
 * @@@
 *
 * @private within the repository
 */
export declare const IS_PIPELINE_LOGIC_VALIDATED: boolean;
/**
 * @@@
 *
 * @private within the repository
 */
export declare const IS_COST_PREVENTED: boolean;
/**
 * Note: [💞] Ignore a discrepancy between file name and entity name
 * TODO: [🧠][🧜‍♂️] Maybe join remoteUrl and path into single value
 */
