import type { KnowledgePiecePreparedJson } from '../../pipeline/PipelineJson/KnowledgePieceJson';
import type { Scraper } from '../_common/Scraper';
import type { ScraperSourceHandler } from '../_common/Scraper';
import type { ExecutionTools } from '../../execution/ExecutionTools';
import type { PrepareAndScrapeOptions } from '../../prepare/PrepareAndScrapeOptions';
import type { ScraperAndConverterMetadata } from '../_common/register/ScraperAndConverterMetadata';
/**
 * Scraper for markdown files
 *
 * @see `documentationUrl` for more details
 * @public exported from `@promptbook/markdown-utils`
 */
export declare class MarkdownScraper implements Scraper {
    private readonly tools;
    private readonly options;
    /**
     * Metadata of the scraper which includes title, mime types, etc.
     */
    get metadata(): ScraperAndConverterMetadata;
    constructor(tools: Pick<ExecutionTools, 'llm'>, options: PrepareAndScrapeOptions);
    /**
     * Scrapes the markdown file and returns the knowledge pieces or `null` if it can't scrape it
     */
    scrape(source: ScraperSourceHandler): Promise<ReadonlyArray<Omit<KnowledgePiecePreparedJson, 'sources' | 'preparationIds'>> | null>;
}
/**
 * TODO: [🪂] Do it in parallel 11:11
 * Note: No need to aggregate usage here, it is done by intercepting the llmTools
 */
